import{s as hs,n as vs,o as bs}from"../chunks/scheduler.85c25b89.js";import{S as _s,i as $s,g as a,s as o,r as d,A as xs,h as r,f as i,c as n,j as l,u as c,x as m,k as v,y as t,a as p,v as g,d as u,t as f,w as h}from"../chunks/index.c9837788.js";import{D as b}from"../chunks/Docstring.5c1d567f.js";import{H as W,E as ys}from"../chunks/EditOnGithub.b65eee75.js";function ws(Ci){let j,$r,or,xr,ve,yr,be,Li="This page contains the API reference documentation for learning rate optimizers included in <code>timm</code>.",wr,_e,Cr,$e,Lr,_,xe,Ao,zt,Ai="Create an optimizer instance via timm registry.",To,Dt,Ti=`Creates and configures an optimizer with appropriate parameter groups and settings.
Supports automatic parameter group creation for weight decay and layer-wise learning
rates, as well as custom parameter grouping.`,zo,qt,zi="Examples:",Do,nr,ir,ye,we,qo,Pt,Di="optimizer = create_optimizer_v2(model, ‘adamw’, lr=1e-3)",Po,mr,sr,Ce,Le,ko,kt,qi=`optimizer = create_optimizer_v2(
…     model, ‘sgd’, lr=0.1, momentum=0.9, weight_decay=1e-4
… )`,Mo,lr,pr,Ae,Te,Eo,Mt,Pi=`optimizer = create_optimizer_v2(
…     model, ‘adam’, lr=1e-3, layer_decay=0.7
… )`,No,dr,cr,ze,De,Oo,Et,ki=`def group_fn(model):
…     return [
…         {‘params’: model.backbone.parameters(), ‘lr’: 1e-4},
…         {‘params’: model.head.parameters(), ‘lr’: 1e-3}
…     ]
optimizer = create_optimizer_v2(
…     model, ‘sgd’, param_group_fn=group_fn
… )`,Io,Nt,Mi=`Note:
Parameter group handling precedence:`,Fo,Ot,Ei="<li>If param_group_fn is provided, it will be used exclusively</li> <li>If layer_decay is provided, layer-wise groups will be created</li> <li>If weight_decay &gt; 0 and filter_bias_and_bn is True, weight decay groups will be created</li> <li>Otherwise, all parameters will be in a single group</li>",Ar,$,qe,Ho,It,Ni="List available optimizer names, optionally filtered.",Bo,Ft,Oi=`List all registered optimizers, with optional filtering using wildcard patterns.
Optimizers can be filtered using include and exclude patterns, and can optionally
return descriptions with each optimizer name.`,Ro,Ht,Ii="Examples:",Go,Bt,Fi=`<blockquote><blockquote><p>list_optimizers()
[‘adam’, ‘adamw’, ‘sgd’, …]</p></blockquote></blockquote>`,So,Rt,Hi=`<blockquote><blockquote><p>list_optimizers([‘la<em>’, ‘nla</em>’])  # List lamb &amp; lars
[‘lamb’, ‘lambc’, ‘larc’, ‘lars’, ‘nlarc’, ‘nlars’]</p></blockquote></blockquote>`,Vo,Gt,Bi=`<blockquote><blockquote><p>list_optimizers(’<em>adam</em>’, exclude_filters=[‘bnb<em>’, ‘fused</em>’])  # Exclude bnb &amp; apex adam optimizers
[‘adam’, ‘adamax’, ‘adamp’, ‘adamw’, ‘nadam’, ‘nadamw’, ‘radam’]</p></blockquote></blockquote>`,Wo,St,Ri=`<blockquote><blockquote><p>list_optimizers(with_description=True)  # Get descriptions
[(‘adabelief’, ‘Adapts learning rate based on gradient prediction error’),
(‘adadelta’, ‘torch.optim Adadelta, Adapts learning rates based on running windows of gradients’),
(‘adafactor’, ‘Memory-efficient implementation of Adam with factored gradients’),
…]</p></blockquote></blockquote>`,Tr,w,Pe,Uo,Vt,Gi="Get optimizer class by name with option to bind default arguments.",Qo,Wt,Si=`Retrieves the optimizer class or a partial function with default arguments bound.
This allows direct instantiation of optimizers with their default configurations
without going through the full factory.`,Ko,Ut,Vi="Examples:",jo,gr,ur,ke,Me,Zo,Qt,Wi=`Adam = get_optimizer_class(‘adam’)
opt = Adam(model.parameters(), lr=1e-3)`,Xo,fr,hr,Ee,Ne,Jo,Kt,Ui=`AdamWithDefaults = get_optimizer_class(‘adam’, bind_defaults=True)
opt = AdamWithDefaults(model.parameters(), lr=1e-3)`,Yo,vr,br,Oe,Ie,en,jt,Qi=`SGD = get_optimizer_class(‘sgd’, bind_defaults=True)  # nesterov=True bound
opt = SGD(model.parameters(), lr=0.1, momentum=0.9)`,zr,Fe,Dr,L,He,tn,Zt,Ki="Implements AdaBelief algorithm. Modified from Adam in PyTorch",an,Xt,ji="reference: AdaBelief Optimizer, adapting stepsizes by the belief in observed gradients, NeurIPS 2020",rn,Jt,Zi=`For a complete table of recommended hyperparameters, see <a href="https://github.com/juntang-zhuang/Adabelief-Optimizer&#39;" rel="nofollow">https://github.com/juntang-zhuang/Adabelief-Optimizer’</a>
For example train/args for EfficientNet see these gists`,on,Yt,Xi='<li>link to train_scipt: <a href="https://gist.github.com/juntang-zhuang/0a501dd51c02278d952cf159bc233037" rel="nofollow">https://gist.github.com/juntang-zhuang/0a501dd51c02278d952cf159bc233037</a></li> <li>link to args.yaml: <a href="https://gist.github.com/juntang-zhuang/517ce3c27022b908bb93f78e4f786dc3" rel="nofollow">https://gist.github.com/juntang-zhuang/517ce3c27022b908bb93f78e4f786dc3</a></li>',nn,J,Be,mn,ea,Ji="Performs a single optimization step.",qr,A,Re,sn,ta,Yi="Implements Adafactor algorithm.",ln,aa,em=`This implementation is based on: <code>Adafactor: Adaptive Learning Rates with Sublinear Memory Cost</code>
(see <a href="https://arxiv.org/abs/1804.04235" rel="nofollow">https://arxiv.org/abs/1804.04235</a>)`,pn,ra,tm=`Note that this optimizer internally adjusts the learning rate depending on the
<em>scale_parameter</em>, <em>relative_step</em> and <em>warmup_init</em> options.`,dn,oa,am=`To use a manual (external) learning rate schedule you should set <code>scale_parameter=False</code> and
<code>relative_step=False</code>.`,cn,Y,Ge,gn,na,rm="Performs a single optimization step.",Pr,R,Se,un,ia,om="PyTorch implementation of BigVision’s Adafactor variant with both single and multi tensor implementations.",fn,ma,nm='Adapted from <a href="https://github.com/google-research/big_vision" rel="nofollow">https://github.com/google-research/big_vision</a> by Ross Wightman',kr,T,Ve,hn,sa,im="Implements the AdaHessian algorithm from “ADAHESSIAN: An Adaptive Second OrderOptimizer for Machine Learning”",vn,ee,We,bn,la,mm="Gets all parameters in all param_groups with gradients",_n,te,Ue,$n,pa,sm="Computes the Hutchinson approximation of the hessian trace and accumulates it for each trainable parameter.",xn,ae,Qe,yn,da,lm="Performs a single optimization step.",wn,re,Ke,Cn,ca,pm="Zeros out the accumalated hessian traces.",Mr,je,Ze,Er,P,Xe,Ln,ga,dm="Implements AdamW algorithm.",An,ua,cm=`The original Adam algorithm was proposed in <code>Adam: A Method for Stochastic Optimization</code><em>.
The AdamW variant was proposed in <code>Decoupled Weight Decay Regularization</code></em>.`,Tn,fa,gm=`.. _Adam\\: A Method for Stochastic Optimization:
<a href="https://arxiv.org/abs/1412.6980" rel="nofollow">https://arxiv.org/abs/1412.6980</a>
.. _Decoupled Weight Decay Regularization:
<a href="https://arxiv.org/abs/1711.05101" rel="nofollow">https://arxiv.org/abs/1711.05101</a>
.. _On the Convergence of Adam and Beyond:
<a href="https://openreview.net/forum?id=ryQu7f-RZ" rel="nofollow">https://openreview.net/forum?id=ryQu7f-RZ</a>`,zn,oe,Je,Dn,ha,um="Performs a single optimization step.",Nr,G,Ye,qn,va,fm=`Implements a pytorch variant of Adan
Adan was proposed in
Adan: Adaptive Nesterov Momentum Algorithm for Faster Optimizing Deep Models[J]. arXiv preprint arXiv:2208.06677, 2022.
<a href="https://arxiv.org/abs/2208.06677" rel="nofollow">https://arxiv.org/abs/2208.06677</a>`,Pn,ne,et,kn,ba,hm="Performs a single optimization step.",Or,Z,tt,Mn,ie,at,En,_a,vm="Perform a single optimization step.",Ir,k,rt,Nn,$a,bm=`Implements a pure pytorch variant of FuseLAMB (NvLamb variant) optimizer from apex.optimizers.FusedLAMB
reference: <a href="https://github.com/NVIDIA/DeepLearningExamples/blob/master/PyTorch/LanguageModeling/Transformer-XL/pytorch/lamb.py" rel="nofollow">https://github.com/NVIDIA/DeepLearningExamples/blob/master/PyTorch/LanguageModeling/Transformer-XL/pytorch/lamb.py</a>`,On,xa,_m="LAMB was proposed in <code>Large Batch Optimization for Deep Learning: Training BERT in 76 minutes</code>_.",In,ya,$m=`.. _Large Batch Optimization for Deep Learning - Training BERT in 76 minutes:
<a href="https://arxiv.org/abs/1904.00962" rel="nofollow">https://arxiv.org/abs/1904.00962</a>
.. _On the Convergence of Adam and Beyond:
<a href="https://openreview.net/forum?id=ryQu7f-RZ" rel="nofollow">https://openreview.net/forum?id=ryQu7f-RZ</a>`,Fn,me,ot,Hn,wa,xm="Performs a single optimization step.",Fr,O,nt,Bn,Ca,ym="LARS for PyTorch",Rn,La,wm='Paper: <code>Large batch training of Convolutional Networks</code> - <a href="https://arxiv.org/pdf/1708.03888.pdf" rel="nofollow">https://arxiv.org/pdf/1708.03888.pdf</a>',Gn,se,it,Sn,Aa,Cm="Performs a single optimization step.",Hr,S,mt,Vn,Ta,Lm="Implements Lion algorithm.",Wn,le,st,Un,za,Am="Performs a single optimization step.",Br,lt,pt,Rr,C,dt,Qn,Da,Tm=`MADGRAD_: A Momentumized, Adaptive, Dual Averaged Gradient Method for Stochastic
Optimization.`,Kn,qa,zm='.. _MADGRAD: <a href="https://arxiv.org/abs/2101.11075" rel="nofollow">https://arxiv.org/abs/2101.11075</a>',jn,Pa,Dm=`MADGRAD is a general purpose optimizer that can be used in place of SGD or
Adam may converge faster and generalize better. Currently GPU-only.
Typically, the same learning rate schedule that is used for SGD or Adam may
be used. The overall learning rate is not comparable to either method and
should be determined by a hyper-parameter sweep.`,Zn,ka,qm=`MADGRAD requires less weight decay than other methods, often as little as
zero. Momentum values used for SGD or Adam’s beta1 should work here also.`,Xn,Ma,Pm="On sparse problems both weight_decay and momentum should be set to 0.",Jn,pe,ct,Yn,Ea,km="Performs a single optimization step.",Gr,z,gt,ei,Na,Mm="Implements Nadam algorithm (a variant of Adam based on Nesterov momentum).",ti,Oa,Em="It has been proposed in <code>Incorporating Nesterov Momentum into Adam</code>__.",ai,Ia,Nm='<strong><a href="http://cs229.stanford.edu/proj2015/054_report.pdf" rel="nofollow">http://cs229.stanford.edu/proj2015/054_report.pdf</a></strong> <a href="http://www.cs.toronto.edu/~fritz/absps/momentum.pdf" rel="nofollow">http://www.cs.toronto.edu/~fritz/absps/momentum.pdf</a>',ri,Fa,Om=`Originally taken from: <a href="https://github.com/pytorch/pytorch/pull/1408" rel="nofollow">https://github.com/pytorch/pytorch/pull/1408</a>
NOTE: Has potential issues but does work well on some problems.`,oi,de,ut,ni,Ha,Im="Performs a single optimization step.",Sr,M,ft,ii,Ba,Fm="Implements NAdamW algorithm.",mi,Ra,Hm=`See Table 1 in <a href="https://arxiv.org/abs/1910.05446" rel="nofollow">https://arxiv.org/abs/1910.05446</a> for the implementation of
the NAdam algorithm (there is also a comment in the code which highlights
the only difference of NAdamW and AdamW).
For further details regarding the algorithm we refer to
<code>Decoupled Weight Decay Regularization</code>_.`,si,Ga,Bm=`.. _Decoupled Weight Decay Regularization:
<a href="https://arxiv.org/abs/1711.05101" rel="nofollow">https://arxiv.org/abs/1711.05101</a>
.. _On the Convergence of Adam and Beyond:
<a href="https://openreview.net/forum?id=ryQu7f-RZ" rel="nofollow">https://openreview.net/forum?id=ryQu7f-RZ</a>`,li,ce,ht,pi,Sa,Rm="Performs a single optimization step.",Vr,V,vt,di,Va,Gm="Implements Novograd algorithm.",ci,ge,bt,gi,Wa,Sm="Performs a single optimization step.",Wr,_t,$t,Ur,x,xt,ui,Ua,Vm="Implements RMSprop algorithm (TensorFlow style epsilon)",fi,Qa,Wm=`NOTE: This is a direct cut-and-paste of PyTorch RMSprop with eps applied before sqrt
and a few other modifications to closer match Tensorflow for matching hyper-params.`,hi,Ka,Um="Noteworthy changes include:",vi,ja,Qm="<li>Epsilon applied inside square-root</li> <li>square_avg initialized to ones</li> <li>LR scaling of update accumulated in momentum buffer</li>",bi,Za,Km=`Proposed by G. Hinton in his
<a href="http://www.cs.toronto.edu/~tijmen/csc321/slides/lecture_slides_lec6.pdf" rel="nofollow">course</a>.`,_i,Xa,jm=`The centered version first appears in <a href="https://arxiv.org/pdf/1308.0850v5.pdf" rel="nofollow">Generating Sequences
With Recurrent Neural Networks</a>.`,$i,ue,yt,xi,Ja,Zm="Performs a single optimization step.",Qr,wt,Ct,Kr,X,Lt,yi,fe,At,wi,Ya,Xm="Performs a single optimization step.",jr,Tt,Zr,_r,Xr;return ve=new W({props:{title:"Optimization",local:"optimization",headingTag:"h1"}}),_e=new W({props:{title:"Optimizers",local:"optimizers",headingTag:"h2"}}),$e=new W({props:{title:"Factory functions",local:"timm.optim.create_optimizer_v2",headingTag:"h3"}}),xe=new b({props:{name:"timm.optim.create_optimizer_v2",anchor:"timm.optim.create_optimizer_v2",parameters:[{name:"model_or_params",val:": Union"},{name:"opt",val:": str = 'sgd'"},{name:"lr",val:": Optional = None"},{name:"weight_decay",val:": float = 0.0"},{name:"momentum",val:": float = 0.9"},{name:"foreach",val:": Optional = None"},{name:"filter_bias_and_bn",val:": bool = True"},{name:"layer_decay",val:": Optional = None"},{name:"param_group_fn",val:": Optional = None"},{name:"**kwargs",val:": Any"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/_optim_factory.py#L837",returnDescription:`<script context="module">export const metadata = 'undefined';<\/script>


<p>Configured optimizer instance.</p>
`}}),we=new W({props:{title:"Basic usage with a model",local:"basic-usage-with-a-model",headingTag:"h1"}}),Le=new W({props:{title:"SGD with momentum and weight decay",local:"sgd-with-momentum-and-weight-decay",headingTag:"h1"}}),Te=new W({props:{title:"Adam with layer-wise learning rate decay",local:"adam-with-layer-wise-learning-rate-decay",headingTag:"h1"}}),De=new W({props:{title:"Custom parameter groups",local:"custom-parameter-groups",headingTag:"h1"}}),qe=new b({props:{name:"timm.optim.list_optimizers",anchor:"timm.optim.list_optimizers",parameters:[{name:"filter",val:": Union = ''"},{name:"exclude_filters",val:": Optional = None"},{name:"with_description",val:": bool = False"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/_optim_factory.py#L737",returnDescription:`<script context="module">export const metadata = 'undefined';<\/script>


<p>List of optimizer names as strings (e.g., [‘adam’, ‘adamw’, …])
If with_description is True:
List of tuples of (name, description) (e.g., [(‘adam’, ‘Adaptive Moment…’), …])</p>
`,returnType:`<script context="module">export const metadata = 'undefined';<\/script>


<p>If with_description is False</p>
`}}),Pe=new b({props:{name:"timm.optim.get_optimizer_class",anchor:"timm.optim.get_optimizer_class",parameters:[{name:"name",val:": str"},{name:"bind_defaults",val:": bool = False"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/_optim_factory.py#L797",returnDescription:`<script context="module">export const metadata = 'undefined';<\/script>


<p>The optimizer class (e.g., torch.optim.Adam)
If bind_defaults is True:
A partial function with default arguments bound</p>
`,returnType:`<script context="module">export const metadata = 'undefined';<\/script>


<p>If bind_defaults is False</p>
`,raiseDescription:`<script context="module">export const metadata = 'undefined';<\/script>


<ul>
<li><code>ValueError</code> — If optimizer name is not found in registry</li>
</ul>
`,raiseType:`<script context="module">export const metadata = 'undefined';<\/script>


<p><code>ValueError</code></p>
`}}),Me=new W({props:{title:"Get raw optimizer class",local:"get-raw-optimizer-class",headingTag:"h1"}}),Ne=new W({props:{title:"Get optimizer with defaults bound",local:"get-optimizer-with-defaults-bound",headingTag:"h1"}}),Ie=new W({props:{title:"Get SGD with nesterov momentum default",local:"get-sgd-with-nesterov-momentum-default",headingTag:"h1"}}),Fe=new W({props:{title:"Optimizer Classes",local:"timm.optim.AdaBelief",headingTag:"h3"}}),He=new b({props:{name:"class timm.optim.AdaBelief",anchor:"timm.optim.AdaBelief",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.001"},{name:"betas",val:" = (0.9, 0.999)"},{name:"eps",val:" = 1e-16"},{name:"weight_decay",val:" = 0"},{name:"amsgrad",val:" = False"},{name:"decoupled_decay",val:" = True"},{name:"fixed_decay",val:" = False"},{name:"rectify",val:" = True"},{name:"degenerated_to_sgd",val:" = True"}],parametersDescription:[{anchor:"timm.optim.AdaBelief.params",description:`<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining
parameter groups`,name:"params"},{anchor:"timm.optim.AdaBelief.lr",description:"<strong>lr</strong> (float, optional) &#x2014; learning rate (default: 1e-3)",name:"lr"},{anchor:"timm.optim.AdaBelief.betas",description:`<strong>betas</strong> (Tuple[float, float], optional) &#x2014; coefficients used for computing
running averages of gradient and its square (default: (0.9, 0.999))`,name:"betas"},{anchor:"timm.optim.AdaBelief.eps",description:`<strong>eps</strong> (float, optional) &#x2014; term added to the denominator to improve
numerical stability (default: 1e-16)`,name:"eps"},{anchor:"timm.optim.AdaBelief.weight_decay",description:"<strong>weight_decay</strong> (float, optional) &#x2014; weight decay (L2 penalty) (default: 0)",name:"weight_decay"},{anchor:"timm.optim.AdaBelief.amsgrad",description:`<strong>amsgrad</strong> (boolean, optional) &#x2014; whether to use the AMSGrad variant of this
algorithm from the paper <code>On the Convergence of Adam and Beyond</code>_
(default: False)`,name:"amsgrad"},{anchor:"timm.optim.AdaBelief.decoupled_decay",description:`<strong>decoupled_decay</strong> (boolean, optional) &#x2014; (default: True) If set as True, then
the optimizer uses decoupled weight decay as in AdamW`,name:"decoupled_decay"},{anchor:"timm.optim.AdaBelief.fixed_decay",description:`<strong>fixed_decay</strong> (boolean, optional) &#x2014; (default: False) This is used when weight<em>decouple
is set as True.
When fixed_decay == True, the weight decay is performed as
$W</em>{new} = W<em>{old} - W</em>{old} \\times decay$.
When fixed<em>decay == False, the weight decay is performed as
$W</em>{new} = W<em>{old} - W</em>{old} \\times decay \\times lr$. Note that in this case, the
weight decay ratio decreases with learning rate (lr).`,name:"fixed_decay"},{anchor:"timm.optim.AdaBelief.rectify",description:`<strong>rectify</strong> (boolean, optional) &#x2014; (default: True) If set as True, then perform the rectified
update similar to RAdam`,name:"rectify"},{anchor:"timm.optim.AdaBelief.degenerated_to_sgd",description:`<strong>degenerated_to_sgd</strong> (boolean, optional) (default &#x2014;True) If set as True, then perform SGD update
when variance of gradient is high`,name:"degenerated_to_sgd"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adabelief.py#L6"}}),Be=new b({props:{name:"step",anchor:"timm.optim.AdaBelief.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.AdaBelief.step.closure",description:`<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model
and returns the loss.`,name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adabelief.py#L106"}}),Re=new b({props:{name:"class timm.optim.Adafactor",anchor:"timm.optim.Adafactor",parameters:[{name:"params",val:""},{name:"lr",val:" = None"},{name:"eps",val:" = 1e-30"},{name:"eps_scale",val:" = 0.001"},{name:"clip_threshold",val:" = 1.0"},{name:"decay_rate",val:" = -0.8"},{name:"betas",val:" = None"},{name:"weight_decay",val:" = 0.0"},{name:"scale_parameter",val:" = True"},{name:"warmup_init",val:" = False"},{name:"min_dim_size_to_factor",val:" = 32"}],parametersDescription:[{anchor:"timm.optim.Adafactor.params",description:"<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining parameter groups",name:"params"},{anchor:"timm.optim.Adafactor.lr",description:"<strong>lr</strong> (float, optional) &#x2014; external learning rate (default: None)",name:"lr"},{anchor:"timm.optim.Adafactor.eps",description:`<strong>eps</strong> (tuple[float, float]) &#x2014; regularization constants for square gradient
and parameter scale respectively (default: (1e-30, 1e-3))`,name:"eps"},{anchor:"timm.optim.Adafactor.clip_threshold",description:"<strong>clip_threshold</strong> (float) &#x2014; threshold of root mean square of final gradient update (default: 1.0)",name:"clip_threshold"},{anchor:"timm.optim.Adafactor.decay_rate",description:"<strong>decay_rate</strong> (float) &#x2014; coefficient used to compute running averages of square gradient (default: -0.8)",name:"decay_rate"},{anchor:"timm.optim.Adafactor.beta1",description:"<strong>beta1</strong> (float) &#x2014; coefficient used for computing running averages of gradient (default: None)",name:"beta1"},{anchor:"timm.optim.Adafactor.weight_decay",description:"<strong>weight_decay</strong> (float, optional) &#x2014; weight decay (L2 penalty) (default: 0)",name:"weight_decay"},{anchor:"timm.optim.Adafactor.scale_parameter",description:"<strong>scale_parameter</strong> (bool) &#x2014; if True, learning rate is scaled by root mean square of parameter (default: True)",name:"scale_parameter"},{anchor:"timm.optim.Adafactor.warmup_init",description:`<strong>warmup_init</strong> (bool) &#x2014; time-dependent learning rate computation depends on
whether warm-up initialization is being used (default: False)`,name:"warmup_init"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adafactor.py#L17"}}),Ge=new b({props:{name:"step",anchor:"timm.optim.Adafactor.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.Adafactor.step.closure",description:"<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model and returns the loss.",name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adafactor.py#L117"}}),Se=new b({props:{name:"class timm.optim.AdafactorBigVision",anchor:"timm.optim.AdafactorBigVision",parameters:[{name:"params",val:""},{name:"lr",val:": float = 1.0"},{name:"min_dim_size_to_factor",val:": int = 32"},{name:"decay_rate",val:": float = 0.8"},{name:"decay_offset",val:": int = 0"},{name:"beta2_cap",val:": float = 0.999"},{name:"momentum",val:": Optional = 0.9"},{name:"momentum_dtype",val:": Union = torch.bfloat16"},{name:"eps",val:": Optional = None"},{name:"weight_decay",val:": float = 0.0"},{name:"clipping_threshold",val:": Optional = None"},{name:"unscaled_wd",val:": bool = False"},{name:"foreach",val:": Optional = False"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adafactor_bv.py#L48"}}),Ve=new b({props:{name:"class timm.optim.Adahessian",anchor:"timm.optim.Adahessian",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.1"},{name:"betas",val:" = (0.9, 0.999)"},{name:"eps",val:" = 1e-08"},{name:"weight_decay",val:" = 0.0"},{name:"hessian_power",val:" = 1.0"},{name:"update_each",val:" = 1"},{name:"n_samples",val:" = 1"},{name:"avg_conv_kernel",val:" = False"}],parametersDescription:[{anchor:"timm.optim.Adahessian.params",description:"<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining parameter groups",name:"params"},{anchor:"timm.optim.Adahessian.lr",description:"<strong>lr</strong> (float, optional) &#x2014; learning rate (default: 0.1)",name:"lr"},{anchor:"timm.optim.Adahessian.betas",description:`<strong>betas</strong> ((float, float), optional) &#x2014; coefficients used for computing running averages of gradient and the
squared hessian trace (default: (0.9, 0.999))`,name:"betas"},{anchor:"timm.optim.Adahessian.eps",description:"<strong>eps</strong> (float, optional) &#x2014; term added to the denominator to improve numerical stability (default: 1e-8)",name:"eps"},{anchor:"timm.optim.Adahessian.weight_decay",description:"<strong>weight_decay</strong> (float, optional) &#x2014; weight decay (L2 penalty) (default: 0.0)",name:"weight_decay"},{anchor:"timm.optim.Adahessian.hessian_power",description:"<strong>hessian_power</strong> (float, optional) &#x2014; exponent of the hessian trace (default: 1.0)",name:"hessian_power"},{anchor:"timm.optim.Adahessian.update_each",description:`<strong>update_each</strong> (int, optional) &#x2014; compute the hessian trace approximation only after <em>this</em> number of steps
(to save time) (default: 1)`,name:"update_each"},{anchor:"timm.optim.Adahessian.n_samples",description:"<strong>n_samples</strong> (int, optional) &#x2014; how many times to sample <code>z</code> for the approximation of the hessian trace (default: 1)",name:"n_samples"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adahessian.py#L9"}}),We=new b({props:{name:"get_params",anchor:"timm.optim.Adahessian.get_params",parameters:[],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adahessian.py#L74"}}),Ue=new b({props:{name:"set_hessian",anchor:"timm.optim.Adahessian.set_hessian",parameters:[],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adahessian.py#L90"}}),Qe=new b({props:{name:"step",anchor:"timm.optim.Adahessian.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.Adahessian.step.closure",description:"<strong>closure</strong> (callable, optional) &#x2014; a closure that reevaluates the model and returns the loss (default &#x2014; None)",name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adahessian.py#L118"}}),Ke=new b({props:{name:"zero_hessian",anchor:"timm.optim.Adahessian.zero_hessian",parameters:[],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adahessian.py#L81"}}),Ze=new b({props:{name:"class timm.optim.AdamP",anchor:"timm.optim.AdamP",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.001"},{name:"betas",val:" = (0.9, 0.999)"},{name:"eps",val:" = 1e-08"},{name:"weight_decay",val:" = 0"},{name:"delta",val:" = 0.1"},{name:"wd_ratio",val:" = 0.1"},{name:"nesterov",val:" = False"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adamp.py#L43"}}),Xe=new b({props:{name:"class timm.optim.AdamW",anchor:"timm.optim.AdamW",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.001"},{name:"betas",val:" = (0.9, 0.999)"},{name:"eps",val:" = 1e-08"},{name:"weight_decay",val:" = 0.01"},{name:"amsgrad",val:" = False"}],parametersDescription:[{anchor:"timm.optim.AdamW.params",description:`<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining
parameter groups`,name:"params"},{anchor:"timm.optim.AdamW.lr",description:"<strong>lr</strong> (float, optional) &#x2014; learning rate (default: 1e-3)",name:"lr"},{anchor:"timm.optim.AdamW.betas",description:`<strong>betas</strong> (Tuple[float, float], optional) &#x2014; coefficients used for computing
running averages of gradient and its square (default: (0.9, 0.999))`,name:"betas"},{anchor:"timm.optim.AdamW.eps",description:`<strong>eps</strong> (float, optional) &#x2014; term added to the denominator to improve
numerical stability (default: 1e-8)`,name:"eps"},{anchor:"timm.optim.AdamW.weight_decay",description:"<strong>weight_decay</strong> (float, optional) &#x2014; weight decay coefficient (default: 1e-2)",name:"weight_decay"},{anchor:"timm.optim.AdamW.amsgrad",description:`<strong>amsgrad</strong> (boolean, optional) &#x2014; whether to use the AMSGrad variant of this
algorithm from the paper <code>On the Convergence of Adam and Beyond</code>_
(default: False)`,name:"amsgrad"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adamw.py#L12"}}),Je=new b({props:{name:"step",anchor:"timm.optim.AdamW.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.AdamW.step.closure",description:`<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model
and returns the loss.`,name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adamw.py#L71"}}),Ye=new b({props:{name:"class timm.optim.Adan",anchor:"timm.optim.Adan",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.001"},{name:"betas",val:" = (0.98, 0.92, 0.99)"},{name:"eps",val:" = 1e-08"},{name:"weight_decay",val:" = 0.0"},{name:"no_prox",val:" = False"}],parametersDescription:[{anchor:"timm.optim.Adan.params",description:"<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining parameter groups.",name:"params"},{anchor:"timm.optim.Adan.lr",description:"<strong>lr</strong> (float, optional) &#x2014; learning rate. (default: 1e-3)",name:"lr"},{anchor:"timm.optim.Adan.betas",description:`<strong>betas</strong> (Tuple[float, float, flot], optional) &#x2014; coefficients used for computing
running averages of gradient and its norm. (default: (0.98, 0.92, 0.99))`,name:"betas"},{anchor:"timm.optim.Adan.eps",description:`<strong>eps</strong> (float, optional) &#x2014; term added to the denominator to improve
numerical stability. (default: 1e-8)`,name:"eps"},{anchor:"timm.optim.Adan.weight_decay",description:"<strong>weight_decay</strong> (float, optional) &#x2014; decoupled weight decay (L2 penalty) (default: 0)",name:"weight_decay"},{anchor:"timm.optim.Adan.no_prox",description:"<strong>no_prox</strong> (bool) &#x2014; how to perform the decoupled weight decay (default: False)",name:"no_prox"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adan.py#L16"}}),et=new b({props:{name:"step",anchor:"timm.optim.Adan.step",parameters:[{name:"closure",val:" = None"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adan.py#L71"}}),tt=new b({props:{name:"class timm.optim.Adopt",anchor:"timm.optim.Adopt",parameters:[{name:"params",val:""},{name:"lr",val:": Union = 0.001"},{name:"betas",val:": Tuple = (0.9, 0.9999)"},{name:"eps",val:": float = 1e-06"},{name:"weight_decay",val:": float = 0.0"},{name:"decoupled",val:": bool = False"},{name:"foreach",val:": Optional = None"},{name:"maximize",val:": bool = False"},{name:"capturable",val:": bool = False"},{name:"differentiable",val:": bool = False"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adopt.py#L53"}}),at=new b({props:{name:"step",anchor:"timm.optim.Adopt.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.Adopt.step.closure",description:`<strong>closure</strong> (Callable, optional) &#x2014; A closure that reevaluates the model
and returns the loss.`,name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/adopt.py#L184"}}),rt=new b({props:{name:"class timm.optim.Lamb",anchor:"timm.optim.Lamb",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.001"},{name:"bias_correction",val:" = True"},{name:"betas",val:" = (0.9, 0.999)"},{name:"eps",val:" = 1e-06"},{name:"weight_decay",val:" = 0.01"},{name:"grad_averaging",val:" = True"},{name:"max_grad_norm",val:" = 1.0"},{name:"trust_clip",val:" = False"},{name:"always_adapt",val:" = False"}],parametersDescription:[{anchor:"timm.optim.Lamb.params",description:"<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining parameter groups.",name:"params"},{anchor:"timm.optim.Lamb.lr",description:"<strong>lr</strong> (float, optional) &#x2014; learning rate. (default: 1e-3)",name:"lr"},{anchor:"timm.optim.Lamb.betas",description:`<strong>betas</strong> (Tuple[float, float], optional) &#x2014; coefficients used for computing
running averages of gradient and its norm. (default: (0.9, 0.999))`,name:"betas"},{anchor:"timm.optim.Lamb.eps",description:`<strong>eps</strong> (float, optional) &#x2014; term added to the denominator to improve
numerical stability. (default: 1e-8)`,name:"eps"},{anchor:"timm.optim.Lamb.weight_decay",description:"<strong>weight_decay</strong> (float, optional) &#x2014; weight decay (L2 penalty) (default: 0)",name:"weight_decay"},{anchor:"timm.optim.Lamb.grad_averaging",description:`<strong>grad_averaging</strong> (bool, optional) &#x2014; whether apply (1-beta2) to grad when
calculating running averages of gradient. (default: True)`,name:"grad_averaging"},{anchor:"timm.optim.Lamb.max_grad_norm",description:"<strong>max_grad_norm</strong> (float, optional) &#x2014; value used to clip global grad norm (default: 1.0)",name:"max_grad_norm"},{anchor:"timm.optim.Lamb.trust_clip",description:"<strong>trust_clip</strong> (bool) &#x2014; enable LAMBC trust ratio clipping (default: False)",name:"trust_clip"},{anchor:"timm.optim.Lamb.always_adapt",description:`<strong>always_adapt</strong> (boolean, optional) &#x2014; Apply adaptive learning rate to 0.0
weight decay parameter (default: False)`,name:"always_adapt"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/lamb.py#L60"}}),ot=new b({props:{name:"step",anchor:"timm.optim.Lamb.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.Lamb.step.closure",description:`<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model
and returns the loss.`,name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/lamb.py#L131"}}),nt=new b({props:{name:"class timm.optim.Lars",anchor:"timm.optim.Lars",parameters:[{name:"params",val:""},{name:"lr",val:" = 1.0"},{name:"momentum",val:" = 0"},{name:"dampening",val:" = 0"},{name:"weight_decay",val:" = 0"},{name:"nesterov",val:" = False"},{name:"trust_coeff",val:" = 0.001"},{name:"eps",val:" = 1e-08"},{name:"trust_clip",val:" = False"},{name:"always_adapt",val:" = False"}],parametersDescription:[{anchor:"timm.optim.Lars.params",description:"<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining parameter groups.",name:"params"},{anchor:"timm.optim.Lars.lr",description:"<strong>lr</strong> (float, optional) &#x2014; learning rate (default: 1.0).",name:"lr"},{anchor:"timm.optim.Lars.momentum",description:"<strong>momentum</strong> (float, optional) &#x2014; momentum factor (default: 0)",name:"momentum"},{anchor:"timm.optim.Lars.weight_decay",description:"<strong>weight_decay</strong> (float, optional) &#x2014; weight decay (L2 penalty) (default: 0)",name:"weight_decay"},{anchor:"timm.optim.Lars.dampening",description:"<strong>dampening</strong> (float, optional) &#x2014; dampening for momentum (default: 0)",name:"dampening"},{anchor:"timm.optim.Lars.nesterov",description:"<strong>nesterov</strong> (bool, optional) &#x2014; enables Nesterov momentum (default: False)",name:"nesterov"},{anchor:"timm.optim.Lars.trust_coeff",description:"<strong>trust_coeff</strong> (float) &#x2014; trust coefficient for computing adaptive lr / trust_ratio (default: 0.001)",name:"trust_coeff"},{anchor:"timm.optim.Lars.eps",description:"<strong>eps</strong> (float) &#x2014; eps for division denominator (default: 1e-8)",name:"eps"},{anchor:"timm.optim.Lars.trust_clip",description:"<strong>trust_clip</strong> (bool) &#x2014; enable LARC trust ratio clipping (default: False)",name:"trust_clip"},{anchor:"timm.optim.Lars.always_adapt",description:"<strong>always_adapt</strong> (bool) &#x2014; always apply LARS LR adapt, otherwise only when group weight_decay != 0 (default: False)",name:"always_adapt"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/lars.py#L17"}}),it=new b({props:{name:"step",anchor:"timm.optim.Lars.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.Lars.step.closure",description:"<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model and returns the loss.",name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/lars.py#L75"}}),mt=new b({props:{name:"class timm.optim.Lion",anchor:"timm.optim.Lion",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.0001"},{name:"betas",val:" = (0.9, 0.99)"},{name:"weight_decay",val:" = 0.0"},{name:"maximize",val:" = False"},{name:"foreach",val:" = None"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/lion.py#L25"}}),st=new b({props:{name:"step",anchor:"timm.optim.Lion.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.Lion.step.closure",description:`<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model
and returns the loss.`,name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/lion.py#L69",returnDescription:`<script context="module">export const metadata = 'undefined';<\/script>


<p>the loss.</p>
`}}),pt=new b({props:{name:"class timm.optim.Lookahead",anchor:"timm.optim.Lookahead",parameters:[{name:"base_optimizer",val:""},{name:"alpha",val:" = 0.5"},{name:"k",val:" = 6"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/lookahead.py#L15"}}),dt=new b({props:{name:"class timm.optim.MADGRAD",anchor:"timm.optim.MADGRAD",parameters:[{name:"params",val:": Any"},{name:"lr",val:": float = 0.01"},{name:"momentum",val:": float = 0.9"},{name:"weight_decay",val:": float = 0"},{name:"eps",val:": float = 1e-06"},{name:"decoupled_decay",val:": bool = False"}],parametersDescription:[{anchor:"timm.optim.MADGRAD.params",description:`<strong>params</strong> (iterable) &#x2014;
Iterable of parameters to optimize or dicts defining parameter groups.`,name:"params"},{anchor:"timm.optim.MADGRAD.lr",description:`<strong>lr</strong> (float) &#x2014;
Learning rate (default: 1e-2).`,name:"lr"},{anchor:"timm.optim.MADGRAD.momentum",description:`<strong>momentum</strong> (float) &#x2014;
Momentum value in  the range [0,1) (default: 0.9).`,name:"momentum"},{anchor:"timm.optim.MADGRAD.weight_decay",description:`<strong>weight_decay</strong> (float) &#x2014;
Weight decay, i.e. a L2 penalty (default: 0).`,name:"weight_decay"},{anchor:"timm.optim.MADGRAD.eps",description:`<strong>eps</strong> (float) &#x2014;
Term added to the denominator outside of the root operation to improve numerical stability. (default: 1e-6).`,name:"eps"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/madgrad.py#L24"}}),ct=new b({props:{name:"step",anchor:"timm.optim.MADGRAD.step",parameters:[{name:"closure",val:": Optional = None"}],parametersDescription:[{anchor:"timm.optim.MADGRAD.step.closure",description:"<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model and returns the loss.",name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/madgrad.py#L90"}}),gt=new b({props:{name:"class timm.optim.Nadam",anchor:"timm.optim.Nadam",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.002"},{name:"betas",val:" = (0.9, 0.999)"},{name:"eps",val:" = 1e-08"},{name:"weight_decay",val:" = 0"},{name:"schedule_decay",val:" = 0.004"}],parametersDescription:[{anchor:"timm.optim.Nadam.params",description:`<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining
parameter groups`,name:"params"},{anchor:"timm.optim.Nadam.lr",description:"<strong>lr</strong> (float, optional) &#x2014; learning rate (default: 2e-3)",name:"lr"},{anchor:"timm.optim.Nadam.betas",description:`<strong>betas</strong> (Tuple[float, float], optional) &#x2014; coefficients used for computing
running averages of gradient and its square`,name:"betas"},{anchor:"timm.optim.Nadam.eps",description:`<strong>eps</strong> (float, optional) &#x2014; term added to the denominator to improve
numerical stability (default: 1e-8)`,name:"eps"},{anchor:"timm.optim.Nadam.weight_decay",description:"<strong>weight_decay</strong> (float, optional) &#x2014; weight decay (L2 penalty) (default: 0)",name:"weight_decay"},{anchor:"timm.optim.Nadam.schedule_decay",description:"<strong>schedule_decay</strong> (float, optional) &#x2014; momentum schedule decay (default: 4e-3)",name:"schedule_decay"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/nadam.py#L7"}}),ut=new b({props:{name:"step",anchor:"timm.optim.Nadam.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.Nadam.step.closure",description:`<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model
and returns the loss.`,name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/nadam.py#L50"}}),ft=new b({props:{name:"class timm.optim.nadamw.NAdamW",anchor:"timm.optim.nadamw.NAdamW",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.001"},{name:"betas",val:" = (0.9, 0.999)"},{name:"eps",val:" = 1e-08"},{name:"weight_decay",val:" = 0.01"},{name:"maximize",val:": bool = False"},{name:"foreach",val:": Optional = None"},{name:"capturable",val:": bool = False"}],parametersDescription:[{anchor:"timm.optim.nadamw.NAdamW.params",description:`<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining
parameter groups`,name:"params"},{anchor:"timm.optim.nadamw.NAdamW.lr",description:"<strong>lr</strong> (float, optional) &#x2014; learning rate (default: 1e-3)",name:"lr"},{anchor:"timm.optim.nadamw.NAdamW.betas",description:`<strong>betas</strong> (Tuple[float, float], optional) &#x2014; coefficients used for computing
running averages of gradient and its square (default: (0.9, 0.999))`,name:"betas"},{anchor:"timm.optim.nadamw.NAdamW.eps",description:`<strong>eps</strong> (float, optional) &#x2014; term added to the denominator to improve
numerical stability (default: 1e-8)`,name:"eps"},{anchor:"timm.optim.nadamw.NAdamW.weight_decay",description:"<strong>weight_decay</strong> (float, optional) &#x2014; weight decay coefficient (default: 1e-2)",name:"weight_decay"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/nadamw.py#L15"}}),ht=new b({props:{name:"step",anchor:"timm.optim.nadamw.NAdamW.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.nadamw.NAdamW.step.closure",description:`<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model
and returns the loss.`,name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/nadamw.py#L80"}}),vt=new b({props:{name:"class timm.optim.NvNovoGrad",anchor:"timm.optim.NvNovoGrad",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.001"},{name:"betas",val:" = (0.95, 0.98)"},{name:"eps",val:" = 1e-08"},{name:"weight_decay",val:" = 0"},{name:"grad_averaging",val:" = False"},{name:"amsgrad",val:" = False"}],parametersDescription:[{anchor:"timm.optim.NvNovoGrad.params",description:`<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining
parameter groups`,name:"params"},{anchor:"timm.optim.NvNovoGrad.lr",description:"<strong>lr</strong> (float, optional) &#x2014; learning rate (default: 1e-3)",name:"lr"},{anchor:"timm.optim.NvNovoGrad.betas",description:`<strong>betas</strong> (Tuple[float, float], optional) &#x2014; coefficients used for computing
running averages of gradient and its square (default: (0.95, 0.98))`,name:"betas"},{anchor:"timm.optim.NvNovoGrad.eps",description:`<strong>eps</strong> (float, optional) &#x2014; term added to the denominator to improve
numerical stability (default: 1e-8)`,name:"eps"},{anchor:"timm.optim.NvNovoGrad.weight_decay",description:`<strong>weight_decay</strong> (float, optional) &#x2014; weight decay (L2 penalty) (default: 0)
grad_averaging &#x2014; gradient averaging`,name:"weight_decay"},{anchor:"timm.optim.NvNovoGrad.amsgrad",description:`<strong>amsgrad</strong> (boolean, optional) &#x2014; whether to use the AMSGrad variant of this
algorithm from the paper <code>On the Convergence of Adam and Beyond</code>_
(default: False)`,name:"amsgrad"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/nvnovograd.py#L13"}}),bt=new b({props:{name:"step",anchor:"timm.optim.NvNovoGrad.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.NvNovoGrad.step.closure",description:"<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model",name:"closure"},{anchor:"timm.optim.NvNovoGrad.step.and",description:"<strong>and</strong> returns the loss. &#x2014;",name:"and"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/nvnovograd.py#L66"}}),$t=new b({props:{name:"class timm.optim.RAdam",anchor:"timm.optim.RAdam",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.001"},{name:"betas",val:" = (0.9, 0.999)"},{name:"eps",val:" = 1e-08"},{name:"weight_decay",val:" = 0"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/radam.py#L10"}}),xt=new b({props:{name:"class timm.optim.RMSpropTF",anchor:"timm.optim.RMSpropTF",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.01"},{name:"alpha",val:" = 0.9"},{name:"eps",val:" = 1e-10"},{name:"weight_decay",val:" = 0"},{name:"momentum",val:" = 0.0"},{name:"centered",val:" = False"},{name:"decoupled_decay",val:" = False"},{name:"lr_in_momentum",val:" = True"}],parametersDescription:[{anchor:"timm.optim.RMSpropTF.params",description:`<strong>params</strong> (iterable) &#x2014; iterable of parameters to optimize or dicts defining
parameter groups`,name:"params"},{anchor:"timm.optim.RMSpropTF.lr",description:"<strong>lr</strong> (float, optional) &#x2014; learning rate (default: 1e-2)",name:"lr"},{anchor:"timm.optim.RMSpropTF.momentum",description:"<strong>momentum</strong> (float, optional) &#x2014; momentum factor (default: 0)",name:"momentum"},{anchor:"timm.optim.RMSpropTF.alpha",description:"<strong>alpha</strong> (float, optional) &#x2014; smoothing (decay) constant (default: 0.9)",name:"alpha"},{anchor:"timm.optim.RMSpropTF.eps",description:`<strong>eps</strong> (float, optional) &#x2014; term added to the denominator to improve
numerical stability (default: 1e-10)`,name:"eps"},{anchor:"timm.optim.RMSpropTF.centered",description:`<strong>centered</strong> (bool, optional)  &#x2014; if <code>True</code>, compute the centered RMSProp,
the gradient is normalized by an estimation of its variance`,name:"centered"},{anchor:"timm.optim.RMSpropTF.weight_decay",description:"<strong>weight_decay</strong> (float, optional) &#x2014; weight decay (L2 penalty) (default: 0)",name:"weight_decay"},{anchor:"timm.optim.RMSpropTF.decoupled_decay",description:'<strong>decoupled_decay</strong> (bool, optional) &#x2014; decoupled weight decay as per <a href="https://arxiv.org/abs/1711.05101" rel="nofollow">https://arxiv.org/abs/1711.05101</a>',name:"decoupled_decay"},{anchor:"timm.optim.RMSpropTF.lr_in_momentum",description:`<strong>lr_in_momentum</strong> (bool, optional) &#x2014; learning rate scaling is included in the momentum buffer
update as per defaults in Tensorflow`,name:"lr_in_momentum"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/rmsprop_tf.py#L14"}}),yt=new b({props:{name:"step",anchor:"timm.optim.RMSpropTF.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.RMSpropTF.step.closure",description:`<strong>closure</strong> (callable, optional) &#x2014; A closure that reevaluates the model
and returns the loss.`,name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/rmsprop_tf.py#L89"}}),Ct=new b({props:{name:"class timm.optim.SGDP",anchor:"timm.optim.SGDP",parameters:[{name:"params",val:""},{name:"lr",val:" = <required parameter>"},{name:"momentum",val:" = 0"},{name:"dampening",val:" = 0"},{name:"weight_decay",val:" = 0"},{name:"nesterov",val:" = False"},{name:"eps",val:" = 1e-08"},{name:"delta",val:" = 0.1"},{name:"wd_ratio",val:" = 0.1"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/sgdp.py#L19"}}),Lt=new b({props:{name:"class timm.optim.sgdw.SGDW",anchor:"timm.optim.sgdw.SGDW",parameters:[{name:"params",val:""},{name:"lr",val:" = 0.001"},{name:"momentum",val:" = 0"},{name:"dampening",val:" = 0"},{name:"weight_decay",val:" = 0"},{name:"nesterov",val:" = False"},{name:"maximize",val:": bool = False"},{name:"foreach",val:": Optional = None"},{name:"differentiable",val:": bool = False"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/sgdw.py#L16"}}),At=new b({props:{name:"step",anchor:"timm.optim.sgdw.SGDW.step",parameters:[{name:"closure",val:" = None"}],parametersDescription:[{anchor:"timm.optim.sgdw.SGDW.step.closure",description:`<strong>closure</strong> (Callable, optional) &#x2014; A closure that reevaluates the model
and returns the loss.`,name:"closure"}],source:"https://github.com/huggingface/pytorch-image-models/blob/vr_2320/timm/optim/sgdw.py#L79"}}),Tt=new ys({props:{source:"https://github.com/huggingface/pytorch-image-models/blob/main/hfdocs/source/reference/optimizers.mdx"}}),{c(){j=a("meta"),$r=o(),or=a("p"),xr=o(),d(ve.$$.fragment),yr=o(),be=a("p"),be.innerHTML=Li,wr=o(),d(_e.$$.fragment),Cr=o(),d($e.$$.fragment),Lr=o(),_=a("div"),d(xe.$$.fragment),Ao=o(),zt=a("p"),zt.textContent=Ai,To=o(),Dt=a("p"),Dt.textContent=Ti,zo=o(),qt=a("p"),qt.textContent=zi,Do=o(),nr=a("blockquote"),ir=a("blockquote"),ye=a("blockquote"),d(we.$$.fragment),qo=o(),Pt=a("p"),Pt.textContent=Di,Po=o(),mr=a("blockquote"),sr=a("blockquote"),Ce=a("blockquote"),d(Le.$$.fragment),ko=o(),kt=a("p"),kt.textContent=qi,Mo=o(),lr=a("blockquote"),pr=a("blockquote"),Ae=a("blockquote"),d(Te.$$.fragment),Eo=o(),Mt=a("p"),Mt.textContent=Pi,No=o(),dr=a("blockquote"),cr=a("blockquote"),ze=a("blockquote"),d(De.$$.fragment),Oo=o(),Et=a("p"),Et.textContent=ki,Io=o(),Nt=a("p"),Nt.textContent=Mi,Fo=o(),Ot=a("ol"),Ot.innerHTML=Ei,Ar=o(),$=a("div"),d(qe.$$.fragment),Ho=o(),It=a("p"),It.textContent=Ni,Bo=o(),Ft=a("p"),Ft.textContent=Oi,Ro=o(),Ht=a("p"),Ht.textContent=Ii,Go=o(),Bt=a("blockquote"),Bt.innerHTML=Fi,So=o(),Rt=a("blockquote"),Rt.innerHTML=Hi,Vo=o(),Gt=a("blockquote"),Gt.innerHTML=Bi,Wo=o(),St=a("blockquote"),St.innerHTML=Ri,Tr=o(),w=a("div"),d(Pe.$$.fragment),Uo=o(),Vt=a("p"),Vt.textContent=Gi,Qo=o(),Wt=a("p"),Wt.textContent=Si,Ko=o(),Ut=a("p"),Ut.textContent=Vi,jo=o(),gr=a("blockquote"),ur=a("blockquote"),ke=a("blockquote"),d(Me.$$.fragment),Zo=o(),Qt=a("p"),Qt.textContent=Wi,Xo=o(),fr=a("blockquote"),hr=a("blockquote"),Ee=a("blockquote"),d(Ne.$$.fragment),Jo=o(),Kt=a("p"),Kt.textContent=Ui,Yo=o(),vr=a("blockquote"),br=a("blockquote"),Oe=a("blockquote"),d(Ie.$$.fragment),en=o(),jt=a("p"),jt.textContent=Qi,zr=o(),d(Fe.$$.fragment),Dr=o(),L=a("div"),d(He.$$.fragment),tn=o(),Zt=a("p"),Zt.textContent=Ki,an=o(),Xt=a("p"),Xt.textContent=ji,rn=o(),Jt=a("p"),Jt.innerHTML=Zi,on=o(),Yt=a("ul"),Yt.innerHTML=Xi,nn=o(),J=a("div"),d(Be.$$.fragment),mn=o(),ea=a("p"),ea.textContent=Ji,qr=o(),A=a("div"),d(Re.$$.fragment),sn=o(),ta=a("p"),ta.textContent=Yi,ln=o(),aa=a("p"),aa.innerHTML=em,pn=o(),ra=a("p"),ra.innerHTML=tm,dn=o(),oa=a("p"),oa.innerHTML=am,cn=o(),Y=a("div"),d(Ge.$$.fragment),gn=o(),na=a("p"),na.textContent=rm,Pr=o(),R=a("div"),d(Se.$$.fragment),un=o(),ia=a("p"),ia.textContent=om,fn=o(),ma=a("p"),ma.innerHTML=nm,kr=o(),T=a("div"),d(Ve.$$.fragment),hn=o(),sa=a("p"),sa.textContent=im,vn=o(),ee=a("div"),d(We.$$.fragment),bn=o(),la=a("p"),la.textContent=mm,_n=o(),te=a("div"),d(Ue.$$.fragment),$n=o(),pa=a("p"),pa.textContent=sm,xn=o(),ae=a("div"),d(Qe.$$.fragment),yn=o(),da=a("p"),da.textContent=lm,wn=o(),re=a("div"),d(Ke.$$.fragment),Cn=o(),ca=a("p"),ca.textContent=pm,Mr=o(),je=a("div"),d(Ze.$$.fragment),Er=o(),P=a("div"),d(Xe.$$.fragment),Ln=o(),ga=a("p"),ga.textContent=dm,An=o(),ua=a("p"),ua.innerHTML=cm,Tn=o(),fa=a("p"),fa.innerHTML=gm,zn=o(),oe=a("div"),d(Je.$$.fragment),Dn=o(),ha=a("p"),ha.textContent=um,Nr=o(),G=a("div"),d(Ye.$$.fragment),qn=o(),va=a("p"),va.innerHTML=fm,Pn=o(),ne=a("div"),d(et.$$.fragment),kn=o(),ba=a("p"),ba.textContent=hm,Or=o(),Z=a("div"),d(tt.$$.fragment),Mn=o(),ie=a("div"),d(at.$$.fragment),En=o(),_a=a("p"),_a.textContent=vm,Ir=o(),k=a("div"),d(rt.$$.fragment),Nn=o(),$a=a("p"),$a.innerHTML=bm,On=o(),xa=a("p"),xa.innerHTML=_m,In=o(),ya=a("p"),ya.innerHTML=$m,Fn=o(),me=a("div"),d(ot.$$.fragment),Hn=o(),wa=a("p"),wa.textContent=xm,Fr=o(),O=a("div"),d(nt.$$.fragment),Bn=o(),Ca=a("p"),Ca.textContent=ym,Rn=o(),La=a("p"),La.innerHTML=wm,Gn=o(),se=a("div"),d(it.$$.fragment),Sn=o(),Aa=a("p"),Aa.textContent=Cm,Hr=o(),S=a("div"),d(mt.$$.fragment),Vn=o(),Ta=a("p"),Ta.textContent=Lm,Wn=o(),le=a("div"),d(st.$$.fragment),Un=o(),za=a("p"),za.textContent=Am,Br=o(),lt=a("div"),d(pt.$$.fragment),Rr=o(),C=a("div"),d(dt.$$.fragment),Qn=o(),Da=a("p"),Da.textContent=Tm,Kn=o(),qa=a("p"),qa.innerHTML=zm,jn=o(),Pa=a("p"),Pa.textContent=Dm,Zn=o(),ka=a("p"),ka.textContent=qm,Xn=o(),Ma=a("p"),Ma.textContent=Pm,Jn=o(),pe=a("div"),d(ct.$$.fragment),Yn=o(),Ea=a("p"),Ea.textContent=km,Gr=o(),z=a("div"),d(gt.$$.fragment),ei=o(),Na=a("p"),Na.textContent=Mm,ti=o(),Oa=a("p"),Oa.innerHTML=Em,ai=o(),Ia=a("p"),Ia.innerHTML=Nm,ri=o(),Fa=a("p"),Fa.innerHTML=Om,oi=o(),de=a("div"),d(ut.$$.fragment),ni=o(),Ha=a("p"),Ha.textContent=Im,Sr=o(),M=a("div"),d(ft.$$.fragment),ii=o(),Ba=a("p"),Ba.textContent=Fm,mi=o(),Ra=a("p"),Ra.innerHTML=Hm,si=o(),Ga=a("p"),Ga.innerHTML=Bm,li=o(),ce=a("div"),d(ht.$$.fragment),pi=o(),Sa=a("p"),Sa.textContent=Rm,Vr=o(),V=a("div"),d(vt.$$.fragment),di=o(),Va=a("p"),Va.textContent=Gm,ci=o(),ge=a("div"),d(bt.$$.fragment),gi=o(),Wa=a("p"),Wa.textContent=Sm,Wr=o(),_t=a("div"),d($t.$$.fragment),Ur=o(),x=a("div"),d(xt.$$.fragment),ui=o(),Ua=a("p"),Ua.textContent=Vm,fi=o(),Qa=a("p"),Qa.textContent=Wm,hi=o(),Ka=a("p"),Ka.textContent=Um,vi=o(),ja=a("ol"),ja.innerHTML=Qm,bi=o(),Za=a("p"),Za.innerHTML=Km,_i=o(),Xa=a("p"),Xa.innerHTML=jm,$i=o(),ue=a("div"),d(yt.$$.fragment),xi=o(),Ja=a("p"),Ja.textContent=Zm,Qr=o(),wt=a("div"),d(Ct.$$.fragment),Kr=o(),X=a("div"),d(Lt.$$.fragment),yi=o(),fe=a("div"),d(At.$$.fragment),wi=o(),Ya=a("p"),Ya.textContent=Xm,jr=o(),d(Tt.$$.fragment),Zr=o(),_r=a("p"),this.h()},l(e){const s=xs("svelte-u9bgzb",document.head);j=r(s,"META",{name:!0,content:!0}),s.forEach(i),$r=n(e),or=r(e,"P",{}),l(or).forEach(i),xr=n(e),c(ve.$$.fragment,e),yr=n(e),be=r(e,"P",{"data-svelte-h":!0}),m(be)!=="svelte-1c6qm22"&&(be.innerHTML=Li),wr=n(e),c(_e.$$.fragment,e),Cr=n(e),c($e.$$.fragment,e),Lr=n(e),_=r(e,"DIV",{class:!0});var y=l(_);c(xe.$$.fragment,y),Ao=n(y),zt=r(y,"P",{"data-svelte-h":!0}),m(zt)!=="svelte-1330e7"&&(zt.textContent=Ai),To=n(y),Dt=r(y,"P",{"data-svelte-h":!0}),m(Dt)!=="svelte-9cjiwr"&&(Dt.textContent=Ti),zo=n(y),qt=r(y,"P",{"data-svelte-h":!0}),m(qt)!=="svelte-kvfsh7"&&(qt.textContent=zi),Do=n(y),nr=r(y,"BLOCKQUOTE",{});var Jm=l(nr);ir=r(Jm,"BLOCKQUOTE",{});var Ym=l(ir);ye=r(Ym,"BLOCKQUOTE",{});var Jr=l(ye);c(we.$$.fragment,Jr),qo=n(Jr),Pt=r(Jr,"P",{"data-svelte-h":!0}),m(Pt)!=="svelte-180ncmf"&&(Pt.textContent=Di),Jr.forEach(i),Ym.forEach(i),Jm.forEach(i),Po=n(y),mr=r(y,"BLOCKQUOTE",{});var es=l(mr);sr=r(es,"BLOCKQUOTE",{});var ts=l(sr);Ce=r(ts,"BLOCKQUOTE",{});var Yr=l(Ce);c(Le.$$.fragment,Yr),ko=n(Yr),kt=r(Yr,"P",{"data-svelte-h":!0}),m(kt)!=="svelte-6yrpk7"&&(kt.textContent=qi),Yr.forEach(i),ts.forEach(i),es.forEach(i),Mo=n(y),lr=r(y,"BLOCKQUOTE",{});var as=l(lr);pr=r(as,"BLOCKQUOTE",{});var rs=l(pr);Ae=r(rs,"BLOCKQUOTE",{});var eo=l(Ae);c(Te.$$.fragment,eo),Eo=n(eo),Mt=r(eo,"P",{"data-svelte-h":!0}),m(Mt)!=="svelte-1vmtu70"&&(Mt.textContent=Pi),eo.forEach(i),rs.forEach(i),as.forEach(i),No=n(y),dr=r(y,"BLOCKQUOTE",{});var os=l(dr);cr=r(os,"BLOCKQUOTE",{});var ns=l(cr);ze=r(ns,"BLOCKQUOTE",{});var to=l(ze);c(De.$$.fragment,to),Oo=n(to),Et=r(to,"P",{"data-svelte-h":!0}),m(Et)!=="svelte-15ovmpe"&&(Et.textContent=ki),to.forEach(i),ns.forEach(i),os.forEach(i),Io=n(y),Nt=r(y,"P",{"data-svelte-h":!0}),m(Nt)!=="svelte-sgpn75"&&(Nt.textContent=Mi),Fo=n(y),Ot=r(y,"OL",{"data-svelte-h":!0}),m(Ot)!=="svelte-psaz57"&&(Ot.innerHTML=Ei),y.forEach(i),Ar=n(e),$=r(e,"DIV",{class:!0});var D=l($);c(qe.$$.fragment,D),Ho=n(D),It=r(D,"P",{"data-svelte-h":!0}),m(It)!=="svelte-1h2sspw"&&(It.textContent=Ni),Bo=n(D),Ft=r(D,"P",{"data-svelte-h":!0}),m(Ft)!=="svelte-1tapwxe"&&(Ft.textContent=Oi),Ro=n(D),Ht=r(D,"P",{"data-svelte-h":!0}),m(Ht)!=="svelte-kvfsh7"&&(Ht.textContent=Ii),Go=n(D),Bt=r(D,"BLOCKQUOTE",{"data-svelte-h":!0}),m(Bt)!=="svelte-m875zf"&&(Bt.innerHTML=Fi),So=n(D),Rt=r(D,"BLOCKQUOTE",{"data-svelte-h":!0}),m(Rt)!=="svelte-1mioyvo"&&(Rt.innerHTML=Hi),Vo=n(D),Gt=r(D,"BLOCKQUOTE",{"data-svelte-h":!0}),m(Gt)!=="svelte-ji9gfr"&&(Gt.innerHTML=Bi),Wo=n(D),St=r(D,"BLOCKQUOTE",{"data-svelte-h":!0}),m(St)!=="svelte-tvmm3x"&&(St.innerHTML=Ri),D.forEach(i),Tr=n(e),w=r(e,"DIV",{class:!0});var E=l(w);c(Pe.$$.fragment,E),Uo=n(E),Vt=r(E,"P",{"data-svelte-h":!0}),m(Vt)!=="svelte-1rcjgrx"&&(Vt.textContent=Gi),Qo=n(E),Wt=r(E,"P",{"data-svelte-h":!0}),m(Wt)!=="svelte-13jhmtj"&&(Wt.textContent=Si),Ko=n(E),Ut=r(E,"P",{"data-svelte-h":!0}),m(Ut)!=="svelte-kvfsh7"&&(Ut.textContent=Vi),jo=n(E),gr=r(E,"BLOCKQUOTE",{});var is=l(gr);ur=r(is,"BLOCKQUOTE",{});var ms=l(ur);ke=r(ms,"BLOCKQUOTE",{});var ao=l(ke);c(Me.$$.fragment,ao),Zo=n(ao),Qt=r(ao,"P",{"data-svelte-h":!0}),m(Qt)!=="svelte-haob3t"&&(Qt.textContent=Wi),ao.forEach(i),ms.forEach(i),is.forEach(i),Xo=n(E),fr=r(E,"BLOCKQUOTE",{});var ss=l(fr);hr=r(ss,"BLOCKQUOTE",{});var ls=l(hr);Ee=r(ls,"BLOCKQUOTE",{});var ro=l(Ee);c(Ne.$$.fragment,ro),Jo=n(ro),Kt=r(ro,"P",{"data-svelte-h":!0}),m(Kt)!=="svelte-1fen2ms"&&(Kt.textContent=Ui),ro.forEach(i),ls.forEach(i),ss.forEach(i),Yo=n(E),vr=r(E,"BLOCKQUOTE",{});var ps=l(vr);br=r(ps,"BLOCKQUOTE",{});var ds=l(br);Oe=r(ds,"BLOCKQUOTE",{});var oo=l(Oe);c(Ie.$$.fragment,oo),en=n(oo),jt=r(oo,"P",{"data-svelte-h":!0}),m(jt)!=="svelte-18pqamq"&&(jt.textContent=Qi),oo.forEach(i),ds.forEach(i),ps.forEach(i),E.forEach(i),zr=n(e),c(Fe.$$.fragment,e),Dr=n(e),L=r(e,"DIV",{class:!0});var I=l(L);c(He.$$.fragment,I),tn=n(I),Zt=r(I,"P",{"data-svelte-h":!0}),m(Zt)!=="svelte-1hnunr4"&&(Zt.textContent=Ki),an=n(I),Xt=r(I,"P",{"data-svelte-h":!0}),m(Xt)!=="svelte-1cjb7xo"&&(Xt.textContent=ji),rn=n(I),Jt=r(I,"P",{"data-svelte-h":!0}),m(Jt)!=="svelte-1347q2l"&&(Jt.innerHTML=Zi),on=n(I),Yt=r(I,"UL",{"data-svelte-h":!0}),m(Yt)!=="svelte-12x3l9q"&&(Yt.innerHTML=Xi),nn=n(I),J=r(I,"DIV",{class:!0});var no=l(J);c(Be.$$.fragment,no),mn=n(no),ea=r(no,"P",{"data-svelte-h":!0}),m(ea)!=="svelte-1gr03w4"&&(ea.textContent=Ji),no.forEach(i),I.forEach(i),qr=n(e),A=r(e,"DIV",{class:!0});var F=l(A);c(Re.$$.fragment,F),sn=n(F),ta=r(F,"P",{"data-svelte-h":!0}),m(ta)!=="svelte-1j9mkxe"&&(ta.textContent=Yi),ln=n(F),aa=r(F,"P",{"data-svelte-h":!0}),m(aa)!=="svelte-1xvyiun"&&(aa.innerHTML=em),pn=n(F),ra=r(F,"P",{"data-svelte-h":!0}),m(ra)!=="svelte-1i7ubkr"&&(ra.innerHTML=tm),dn=n(F),oa=r(F,"P",{"data-svelte-h":!0}),m(oa)!=="svelte-96f97i"&&(oa.innerHTML=am),cn=n(F),Y=r(F,"DIV",{class:!0});var io=l(Y);c(Ge.$$.fragment,io),gn=n(io),na=r(io,"P",{"data-svelte-h":!0}),m(na)!=="svelte-1gr03w4"&&(na.textContent=rm),io.forEach(i),F.forEach(i),Pr=n(e),R=r(e,"DIV",{class:!0});var er=l(R);c(Se.$$.fragment,er),un=n(er),ia=r(er,"P",{"data-svelte-h":!0}),m(ia)!=="svelte-19t8yzj"&&(ia.textContent=om),fn=n(er),ma=r(er,"P",{"data-svelte-h":!0}),m(ma)!=="svelte-aajaln"&&(ma.innerHTML=nm),er.forEach(i),kr=n(e),T=r(e,"DIV",{class:!0});var H=l(T);c(Ve.$$.fragment,H),hn=n(H),sa=r(H,"P",{"data-svelte-h":!0}),m(sa)!=="svelte-1cuo0rh"&&(sa.textContent=im),vn=n(H),ee=r(H,"DIV",{class:!0});var mo=l(ee);c(We.$$.fragment,mo),bn=n(mo),la=r(mo,"P",{"data-svelte-h":!0}),m(la)!=="svelte-1jz1hl7"&&(la.textContent=mm),mo.forEach(i),_n=n(H),te=r(H,"DIV",{class:!0});var so=l(te);c(Ue.$$.fragment,so),$n=n(so),pa=r(so,"P",{"data-svelte-h":!0}),m(pa)!=="svelte-1y1oyzd"&&(pa.textContent=sm),so.forEach(i),xn=n(H),ae=r(H,"DIV",{class:!0});var lo=l(ae);c(Qe.$$.fragment,lo),yn=n(lo),da=r(lo,"P",{"data-svelte-h":!0}),m(da)!=="svelte-1gr03w4"&&(da.textContent=lm),lo.forEach(i),wn=n(H),re=r(H,"DIV",{class:!0});var po=l(re);c(Ke.$$.fragment,po),Cn=n(po),ca=r(po,"P",{"data-svelte-h":!0}),m(ca)!=="svelte-4lvf5h"&&(ca.textContent=pm),po.forEach(i),H.forEach(i),Mr=n(e),je=r(e,"DIV",{class:!0});var cs=l(je);c(Ze.$$.fragment,cs),cs.forEach(i),Er=n(e),P=r(e,"DIV",{class:!0});var U=l(P);c(Xe.$$.fragment,U),Ln=n(U),ga=r(U,"P",{"data-svelte-h":!0}),m(ga)!=="svelte-c51pd7"&&(ga.textContent=dm),An=n(U),ua=r(U,"P",{"data-svelte-h":!0}),m(ua)!=="svelte-1cgyzi6"&&(ua.innerHTML=cm),Tn=n(U),fa=r(U,"P",{"data-svelte-h":!0}),m(fa)!=="svelte-1pe3ewc"&&(fa.innerHTML=gm),zn=n(U),oe=r(U,"DIV",{class:!0});var co=l(oe);c(Je.$$.fragment,co),Dn=n(co),ha=r(co,"P",{"data-svelte-h":!0}),m(ha)!=="svelte-1gr03w4"&&(ha.textContent=um),co.forEach(i),U.forEach(i),Nr=n(e),G=r(e,"DIV",{class:!0});var tr=l(G);c(Ye.$$.fragment,tr),qn=n(tr),va=r(tr,"P",{"data-svelte-h":!0}),m(va)!=="svelte-acz7r2"&&(va.innerHTML=fm),Pn=n(tr),ne=r(tr,"DIV",{class:!0});var go=l(ne);c(et.$$.fragment,go),kn=n(go),ba=r(go,"P",{"data-svelte-h":!0}),m(ba)!=="svelte-1gr03w4"&&(ba.textContent=hm),go.forEach(i),tr.forEach(i),Or=n(e),Z=r(e,"DIV",{class:!0});var uo=l(Z);c(tt.$$.fragment,uo),Mn=n(uo),ie=r(uo,"DIV",{class:!0});var fo=l(ie);c(at.$$.fragment,fo),En=n(fo),_a=r(fo,"P",{"data-svelte-h":!0}),m(_a)!=="svelte-1siu6mf"&&(_a.textContent=vm),fo.forEach(i),uo.forEach(i),Ir=n(e),k=r(e,"DIV",{class:!0});var Q=l(k);c(rt.$$.fragment,Q),Nn=n(Q),$a=r(Q,"P",{"data-svelte-h":!0}),m($a)!=="svelte-d5zqgn"&&($a.innerHTML=bm),On=n(Q),xa=r(Q,"P",{"data-svelte-h":!0}),m(xa)!=="svelte-1wamkfv"&&(xa.innerHTML=_m),In=n(Q),ya=r(Q,"P",{"data-svelte-h":!0}),m(ya)!=="svelte-dty621"&&(ya.innerHTML=$m),Fn=n(Q),me=r(Q,"DIV",{class:!0});var ho=l(me);c(ot.$$.fragment,ho),Hn=n(ho),wa=r(ho,"P",{"data-svelte-h":!0}),m(wa)!=="svelte-1gr03w4"&&(wa.textContent=xm),ho.forEach(i),Q.forEach(i),Fr=n(e),O=r(e,"DIV",{class:!0});var he=l(O);c(nt.$$.fragment,he),Bn=n(he),Ca=r(he,"P",{"data-svelte-h":!0}),m(Ca)!=="svelte-vzcsb8"&&(Ca.textContent=ym),Rn=n(he),La=r(he,"P",{"data-svelte-h":!0}),m(La)!=="svelte-euart9"&&(La.innerHTML=wm),Gn=n(he),se=r(he,"DIV",{class:!0});var vo=l(se);c(it.$$.fragment,vo),Sn=n(vo),Aa=r(vo,"P",{"data-svelte-h":!0}),m(Aa)!=="svelte-1gr03w4"&&(Aa.textContent=Cm),vo.forEach(i),he.forEach(i),Hr=n(e),S=r(e,"DIV",{class:!0});var ar=l(S);c(mt.$$.fragment,ar),Vn=n(ar),Ta=r(ar,"P",{"data-svelte-h":!0}),m(Ta)!=="svelte-pwyp7b"&&(Ta.textContent=Lm),Wn=n(ar),le=r(ar,"DIV",{class:!0});var bo=l(le);c(st.$$.fragment,bo),Un=n(bo),za=r(bo,"P",{"data-svelte-h":!0}),m(za)!=="svelte-1gr03w4"&&(za.textContent=Am),bo.forEach(i),ar.forEach(i),Br=n(e),lt=r(e,"DIV",{class:!0});var gs=l(lt);c(pt.$$.fragment,gs),gs.forEach(i),Rr=n(e),C=r(e,"DIV",{class:!0});var N=l(C);c(dt.$$.fragment,N),Qn=n(N),Da=r(N,"P",{"data-svelte-h":!0}),m(Da)!=="svelte-wmmdpx"&&(Da.textContent=Tm),Kn=n(N),qa=r(N,"P",{"data-svelte-h":!0}),m(qa)!=="svelte-12dyngi"&&(qa.innerHTML=zm),jn=n(N),Pa=r(N,"P",{"data-svelte-h":!0}),m(Pa)!=="svelte-qjjdis"&&(Pa.textContent=Dm),Zn=n(N),ka=r(N,"P",{"data-svelte-h":!0}),m(ka)!=="svelte-rosfou"&&(ka.textContent=qm),Xn=n(N),Ma=r(N,"P",{"data-svelte-h":!0}),m(Ma)!=="svelte-hlwvkn"&&(Ma.textContent=Pm),Jn=n(N),pe=r(N,"DIV",{class:!0});var _o=l(pe);c(ct.$$.fragment,_o),Yn=n(_o),Ea=r(_o,"P",{"data-svelte-h":!0}),m(Ea)!=="svelte-1gr03w4"&&(Ea.textContent=km),_o.forEach(i),N.forEach(i),Gr=n(e),z=r(e,"DIV",{class:!0});var B=l(z);c(gt.$$.fragment,B),ei=n(B),Na=r(B,"P",{"data-svelte-h":!0}),m(Na)!=="svelte-1ss2c23"&&(Na.textContent=Mm),ti=n(B),Oa=r(B,"P",{"data-svelte-h":!0}),m(Oa)!=="svelte-ewqetr"&&(Oa.innerHTML=Em),ai=n(B),Ia=r(B,"P",{"data-svelte-h":!0}),m(Ia)!=="svelte-1q705lb"&&(Ia.innerHTML=Nm),ri=n(B),Fa=r(B,"P",{"data-svelte-h":!0}),m(Fa)!=="svelte-14ul3re"&&(Fa.innerHTML=Om),oi=n(B),de=r(B,"DIV",{class:!0});var $o=l(de);c(ut.$$.fragment,$o),ni=n($o),Ha=r($o,"P",{"data-svelte-h":!0}),m(Ha)!=="svelte-1gr03w4"&&(Ha.textContent=Im),$o.forEach(i),B.forEach(i),Sr=n(e),M=r(e,"DIV",{class:!0});var K=l(M);c(ft.$$.fragment,K),ii=n(K),Ba=r(K,"P",{"data-svelte-h":!0}),m(Ba)!=="svelte-3mtxcr"&&(Ba.textContent=Fm),mi=n(K),Ra=r(K,"P",{"data-svelte-h":!0}),m(Ra)!=="svelte-797qvx"&&(Ra.innerHTML=Hm),si=n(K),Ga=r(K,"P",{"data-svelte-h":!0}),m(Ga)!=="svelte-1qa39gq"&&(Ga.innerHTML=Bm),li=n(K),ce=r(K,"DIV",{class:!0});var xo=l(ce);c(ht.$$.fragment,xo),pi=n(xo),Sa=r(xo,"P",{"data-svelte-h":!0}),m(Sa)!=="svelte-1gr03w4"&&(Sa.textContent=Rm),xo.forEach(i),K.forEach(i),Vr=n(e),V=r(e,"DIV",{class:!0});var rr=l(V);c(vt.$$.fragment,rr),di=n(rr),Va=r(rr,"P",{"data-svelte-h":!0}),m(Va)!=="svelte-5vv99d"&&(Va.textContent=Gm),ci=n(rr),ge=r(rr,"DIV",{class:!0});var yo=l(ge);c(bt.$$.fragment,yo),gi=n(yo),Wa=r(yo,"P",{"data-svelte-h":!0}),m(Wa)!=="svelte-1gr03w4"&&(Wa.textContent=Sm),yo.forEach(i),rr.forEach(i),Wr=n(e),_t=r(e,"DIV",{class:!0});var us=l(_t);c($t.$$.fragment,us),us.forEach(i),Ur=n(e),x=r(e,"DIV",{class:!0});var q=l(x);c(xt.$$.fragment,q),ui=n(q),Ua=r(q,"P",{"data-svelte-h":!0}),m(Ua)!=="svelte-1tqv0s5"&&(Ua.textContent=Vm),fi=n(q),Qa=r(q,"P",{"data-svelte-h":!0}),m(Qa)!=="svelte-g10xv4"&&(Qa.textContent=Wm),hi=n(q),Ka=r(q,"P",{"data-svelte-h":!0}),m(Ka)!=="svelte-1acg3vg"&&(Ka.textContent=Um),vi=n(q),ja=r(q,"OL",{"data-svelte-h":!0}),m(ja)!=="svelte-15y6o6y"&&(ja.innerHTML=Qm),bi=n(q),Za=r(q,"P",{"data-svelte-h":!0}),m(Za)!=="svelte-1yvkj2h"&&(Za.innerHTML=Km),_i=n(q),Xa=r(q,"P",{"data-svelte-h":!0}),m(Xa)!=="svelte-53x1ow"&&(Xa.innerHTML=jm),$i=n(q),ue=r(q,"DIV",{class:!0});var wo=l(ue);c(yt.$$.fragment,wo),xi=n(wo),Ja=r(wo,"P",{"data-svelte-h":!0}),m(Ja)!=="svelte-1gr03w4"&&(Ja.textContent=Zm),wo.forEach(i),q.forEach(i),Qr=n(e),wt=r(e,"DIV",{class:!0});var fs=l(wt);c(Ct.$$.fragment,fs),fs.forEach(i),Kr=n(e),X=r(e,"DIV",{class:!0});var Co=l(X);c(Lt.$$.fragment,Co),yi=n(Co),fe=r(Co,"DIV",{class:!0});var Lo=l(fe);c(At.$$.fragment,Lo),wi=n(Lo),Ya=r(Lo,"P",{"data-svelte-h":!0}),m(Ya)!=="svelte-1gr03w4"&&(Ya.textContent=Xm),Lo.forEach(i),Co.forEach(i),jr=n(e),c(Tt.$$.fragment,e),Zr=n(e),_r=r(e,"P",{}),l(_r).forEach(i),this.h()},h(){v(j,"name","hf:doc:metadata"),v(j,"content",Cs),v(_,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v($,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(w,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(J,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(L,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(Y,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(A,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(R,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(ee,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(te,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(ae,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(re,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(T,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(je,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(oe,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(P,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(ne,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(G,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(ie,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(Z,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(me,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(k,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(se,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(O,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(le,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(S,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(lt,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(pe,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(C,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(de,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(z,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(ce,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(M,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(ge,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(V,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(_t,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(ue,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(x,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(wt,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(fe,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),v(X,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8")},m(e,s){t(document.head,j),p(e,$r,s),p(e,or,s),p(e,xr,s),g(ve,e,s),p(e,yr,s),p(e,be,s),p(e,wr,s),g(_e,e,s),p(e,Cr,s),g($e,e,s),p(e,Lr,s),p(e,_,s),g(xe,_,null),t(_,Ao),t(_,zt),t(_,To),t(_,Dt),t(_,zo),t(_,qt),t(_,Do),t(_,nr),t(nr,ir),t(ir,ye),g(we,ye,null),t(ye,qo),t(ye,Pt),t(_,Po),t(_,mr),t(mr,sr),t(sr,Ce),g(Le,Ce,null),t(Ce,ko),t(Ce,kt),t(_,Mo),t(_,lr),t(lr,pr),t(pr,Ae),g(Te,Ae,null),t(Ae,Eo),t(Ae,Mt),t(_,No),t(_,dr),t(dr,cr),t(cr,ze),g(De,ze,null),t(ze,Oo),t(ze,Et),t(_,Io),t(_,Nt),t(_,Fo),t(_,Ot),p(e,Ar,s),p(e,$,s),g(qe,$,null),t($,Ho),t($,It),t($,Bo),t($,Ft),t($,Ro),t($,Ht),t($,Go),t($,Bt),t($,So),t($,Rt),t($,Vo),t($,Gt),t($,Wo),t($,St),p(e,Tr,s),p(e,w,s),g(Pe,w,null),t(w,Uo),t(w,Vt),t(w,Qo),t(w,Wt),t(w,Ko),t(w,Ut),t(w,jo),t(w,gr),t(gr,ur),t(ur,ke),g(Me,ke,null),t(ke,Zo),t(ke,Qt),t(w,Xo),t(w,fr),t(fr,hr),t(hr,Ee),g(Ne,Ee,null),t(Ee,Jo),t(Ee,Kt),t(w,Yo),t(w,vr),t(vr,br),t(br,Oe),g(Ie,Oe,null),t(Oe,en),t(Oe,jt),p(e,zr,s),g(Fe,e,s),p(e,Dr,s),p(e,L,s),g(He,L,null),t(L,tn),t(L,Zt),t(L,an),t(L,Xt),t(L,rn),t(L,Jt),t(L,on),t(L,Yt),t(L,nn),t(L,J),g(Be,J,null),t(J,mn),t(J,ea),p(e,qr,s),p(e,A,s),g(Re,A,null),t(A,sn),t(A,ta),t(A,ln),t(A,aa),t(A,pn),t(A,ra),t(A,dn),t(A,oa),t(A,cn),t(A,Y),g(Ge,Y,null),t(Y,gn),t(Y,na),p(e,Pr,s),p(e,R,s),g(Se,R,null),t(R,un),t(R,ia),t(R,fn),t(R,ma),p(e,kr,s),p(e,T,s),g(Ve,T,null),t(T,hn),t(T,sa),t(T,vn),t(T,ee),g(We,ee,null),t(ee,bn),t(ee,la),t(T,_n),t(T,te),g(Ue,te,null),t(te,$n),t(te,pa),t(T,xn),t(T,ae),g(Qe,ae,null),t(ae,yn),t(ae,da),t(T,wn),t(T,re),g(Ke,re,null),t(re,Cn),t(re,ca),p(e,Mr,s),p(e,je,s),g(Ze,je,null),p(e,Er,s),p(e,P,s),g(Xe,P,null),t(P,Ln),t(P,ga),t(P,An),t(P,ua),t(P,Tn),t(P,fa),t(P,zn),t(P,oe),g(Je,oe,null),t(oe,Dn),t(oe,ha),p(e,Nr,s),p(e,G,s),g(Ye,G,null),t(G,qn),t(G,va),t(G,Pn),t(G,ne),g(et,ne,null),t(ne,kn),t(ne,ba),p(e,Or,s),p(e,Z,s),g(tt,Z,null),t(Z,Mn),t(Z,ie),g(at,ie,null),t(ie,En),t(ie,_a),p(e,Ir,s),p(e,k,s),g(rt,k,null),t(k,Nn),t(k,$a),t(k,On),t(k,xa),t(k,In),t(k,ya),t(k,Fn),t(k,me),g(ot,me,null),t(me,Hn),t(me,wa),p(e,Fr,s),p(e,O,s),g(nt,O,null),t(O,Bn),t(O,Ca),t(O,Rn),t(O,La),t(O,Gn),t(O,se),g(it,se,null),t(se,Sn),t(se,Aa),p(e,Hr,s),p(e,S,s),g(mt,S,null),t(S,Vn),t(S,Ta),t(S,Wn),t(S,le),g(st,le,null),t(le,Un),t(le,za),p(e,Br,s),p(e,lt,s),g(pt,lt,null),p(e,Rr,s),p(e,C,s),g(dt,C,null),t(C,Qn),t(C,Da),t(C,Kn),t(C,qa),t(C,jn),t(C,Pa),t(C,Zn),t(C,ka),t(C,Xn),t(C,Ma),t(C,Jn),t(C,pe),g(ct,pe,null),t(pe,Yn),t(pe,Ea),p(e,Gr,s),p(e,z,s),g(gt,z,null),t(z,ei),t(z,Na),t(z,ti),t(z,Oa),t(z,ai),t(z,Ia),t(z,ri),t(z,Fa),t(z,oi),t(z,de),g(ut,de,null),t(de,ni),t(de,Ha),p(e,Sr,s),p(e,M,s),g(ft,M,null),t(M,ii),t(M,Ba),t(M,mi),t(M,Ra),t(M,si),t(M,Ga),t(M,li),t(M,ce),g(ht,ce,null),t(ce,pi),t(ce,Sa),p(e,Vr,s),p(e,V,s),g(vt,V,null),t(V,di),t(V,Va),t(V,ci),t(V,ge),g(bt,ge,null),t(ge,gi),t(ge,Wa),p(e,Wr,s),p(e,_t,s),g($t,_t,null),p(e,Ur,s),p(e,x,s),g(xt,x,null),t(x,ui),t(x,Ua),t(x,fi),t(x,Qa),t(x,hi),t(x,Ka),t(x,vi),t(x,ja),t(x,bi),t(x,Za),t(x,_i),t(x,Xa),t(x,$i),t(x,ue),g(yt,ue,null),t(ue,xi),t(ue,Ja),p(e,Qr,s),p(e,wt,s),g(Ct,wt,null),p(e,Kr,s),p(e,X,s),g(Lt,X,null),t(X,yi),t(X,fe),g(At,fe,null),t(fe,wi),t(fe,Ya),p(e,jr,s),g(Tt,e,s),p(e,Zr,s),p(e,_r,s),Xr=!0},p:vs,i(e){Xr||(u(ve.$$.fragment,e),u(_e.$$.fragment,e),u($e.$$.fragment,e),u(xe.$$.fragment,e),u(we.$$.fragment,e),u(Le.$$.fragment,e),u(Te.$$.fragment,e),u(De.$$.fragment,e),u(qe.$$.fragment,e),u(Pe.$$.fragment,e),u(Me.$$.fragment,e),u(Ne.$$.fragment,e),u(Ie.$$.fragment,e),u(Fe.$$.fragment,e),u(He.$$.fragment,e),u(Be.$$.fragment,e),u(Re.$$.fragment,e),u(Ge.$$.fragment,e),u(Se.$$.fragment,e),u(Ve.$$.fragment,e),u(We.$$.fragment,e),u(Ue.$$.fragment,e),u(Qe.$$.fragment,e),u(Ke.$$.fragment,e),u(Ze.$$.fragment,e),u(Xe.$$.fragment,e),u(Je.$$.fragment,e),u(Ye.$$.fragment,e),u(et.$$.fragment,e),u(tt.$$.fragment,e),u(at.$$.fragment,e),u(rt.$$.fragment,e),u(ot.$$.fragment,e),u(nt.$$.fragment,e),u(it.$$.fragment,e),u(mt.$$.fragment,e),u(st.$$.fragment,e),u(pt.$$.fragment,e),u(dt.$$.fragment,e),u(ct.$$.fragment,e),u(gt.$$.fragment,e),u(ut.$$.fragment,e),u(ft.$$.fragment,e),u(ht.$$.fragment,e),u(vt.$$.fragment,e),u(bt.$$.fragment,e),u($t.$$.fragment,e),u(xt.$$.fragment,e),u(yt.$$.fragment,e),u(Ct.$$.fragment,e),u(Lt.$$.fragment,e),u(At.$$.fragment,e),u(Tt.$$.fragment,e),Xr=!0)},o(e){f(ve.$$.fragment,e),f(_e.$$.fragment,e),f($e.$$.fragment,e),f(xe.$$.fragment,e),f(we.$$.fragment,e),f(Le.$$.fragment,e),f(Te.$$.fragment,e),f(De.$$.fragment,e),f(qe.$$.fragment,e),f(Pe.$$.fragment,e),f(Me.$$.fragment,e),f(Ne.$$.fragment,e),f(Ie.$$.fragment,e),f(Fe.$$.fragment,e),f(He.$$.fragment,e),f(Be.$$.fragment,e),f(Re.$$.fragment,e),f(Ge.$$.fragment,e),f(Se.$$.fragment,e),f(Ve.$$.fragment,e),f(We.$$.fragment,e),f(Ue.$$.fragment,e),f(Qe.$$.fragment,e),f(Ke.$$.fragment,e),f(Ze.$$.fragment,e),f(Xe.$$.fragment,e),f(Je.$$.fragment,e),f(Ye.$$.fragment,e),f(et.$$.fragment,e),f(tt.$$.fragment,e),f(at.$$.fragment,e),f(rt.$$.fragment,e),f(ot.$$.fragment,e),f(nt.$$.fragment,e),f(it.$$.fragment,e),f(mt.$$.fragment,e),f(st.$$.fragment,e),f(pt.$$.fragment,e),f(dt.$$.fragment,e),f(ct.$$.fragment,e),f(gt.$$.fragment,e),f(ut.$$.fragment,e),f(ft.$$.fragment,e),f(ht.$$.fragment,e),f(vt.$$.fragment,e),f(bt.$$.fragment,e),f($t.$$.fragment,e),f(xt.$$.fragment,e),f(yt.$$.fragment,e),f(Ct.$$.fragment,e),f(Lt.$$.fragment,e),f(At.$$.fragment,e),f(Tt.$$.fragment,e),Xr=!1},d(e){e&&(i($r),i(or),i(xr),i(yr),i(be),i(wr),i(Cr),i(Lr),i(_),i(Ar),i($),i(Tr),i(w),i(zr),i(Dr),i(L),i(qr),i(A),i(Pr),i(R),i(kr),i(T),i(Mr),i(je),i(Er),i(P),i(Nr),i(G),i(Or),i(Z),i(Ir),i(k),i(Fr),i(O),i(Hr),i(S),i(Br),i(lt),i(Rr),i(C),i(Gr),i(z),i(Sr),i(M),i(Vr),i(V),i(Wr),i(_t),i(Ur),i(x),i(Qr),i(wt),i(Kr),i(X),i(jr),i(Zr),i(_r)),i(j),h(ve,e),h(_e,e),h($e,e),h(xe),h(we),h(Le),h(Te),h(De),h(qe),h(Pe),h(Me),h(Ne),h(Ie),h(Fe,e),h(He),h(Be),h(Re),h(Ge),h(Se),h(Ve),h(We),h(Ue),h(Qe),h(Ke),h(Ze),h(Xe),h(Je),h(Ye),h(et),h(tt),h(at),h(rt),h(ot),h(nt),h(it),h(mt),h(st),h(pt),h(dt),h(ct),h(gt),h(ut),h(ft),h(ht),h(vt),h(bt),h($t),h(xt),h(yt),h(Ct),h(Lt),h(At),h(Tt,e)}}}const Cs='{"title":"Optimization","local":"optimization","sections":[{"title":"Optimizers","local":"optimizers","sections":[{"title":"Factory functions","local":"timm.optim.create_optimizer_v2","sections":[],"depth":3}],"depth":2}],"depth":1}';function Ls(Ci){return bs(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class qs extends _s{constructor(j){super(),$s(this,j,Ls,ws,hs,{})}}export{qs as component};
